@@ -7,9 +7,8 @@ from netaudio.console.commands import (
     SubscriptionCommand,
 )
 
-
 def main() -> int:
-    application = Application("netaudio", "0.0.1", complete=True)
+    application = Application("netaudio", "", complete=True)
     application.add(ChannelCommand())
     application.add(ConfigCommand())
     application.add(DeviceCommand())
